@@ -3,7 +3,6 @@ try:
     import logging
     import os
     import json
-    import traceback
     import threading
     from zcrmsdk.src.com.zoho.api.authenticator.store.token_store import TokenStore
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
@@ -12,13 +11,14 @@ try:
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
     from zcrmsdk.src.com.zoho.api.authenticator.token import Token
     from zcrmsdk.src.com.zoho.api.logger import Logger, SDKLogger
-    from zcrmsdk.src.com.zoho.crm.api.user_proxy import UserProxy
+    from zcrmsdk.src.com.zoho.crm.api.request_proxy import RequestProxy
+    from zcrmsdk.src.com.zoho.crm.api.sdk_config import SDKConfig
+
 
 except Exception:
     import logging
     import os
     import json
-    import traceback
     import threading
     from ...api.authenticator.store.token_store import TokenStore
     from ..api.exception import SDKException
@@ -27,7 +27,8 @@ except Exception:
     from ..api.util.constants import Constants
     from ...api.authenticator.token import Token
     from ...api.logger import Logger, SDKLogger
-    from .user_proxy import UserProxy
+    from .request_proxy import RequestProxy
+    from .sdk_config import SDKConfig
 
 
 class Initializer(object):
@@ -41,8 +42,8 @@ class Initializer(object):
         self.user = None
         self.store = None
         self.token = None
-        self.auto_refresh_fields = None
-        self.user_proxy = None
+        self.sdk_config = None
+        self.request_proxy = None
         self.resource_path = None
 
     json_details = None
@@ -51,7 +52,7 @@ class Initializer(object):
     LOCAL.init = None
 
     @staticmethod
-    def initialize(user, environment, token, store, auto_refresh_fields, resource_path, logger=None, proxy=None):
+    def initialize(user, environment, token, store, sdk_config, resource_path, logger=None, proxy=None):
 
         """
         The method to initialize the SDK.
@@ -61,10 +62,10 @@ class Initializer(object):
             environment (DataCenter.Environment) : An Environment class instance containing the CRM API base URL and Accounts URL.
             token (Token) : A Token class instance containing the OAuth client application information.
             store (TokenStore) : A TokenStore class instance containing the token store information.
-            auto_refresh_fields (bool) : A Boolean value to allow or prevent auto-refreshing of the modules' fields in the background.
+            sdk_config (SDKConfig) : A SDKConfig class instance containing the configuration.
             resource_path (str) : A String containing the absolute directory path to store user specific JSON files containing module fields information.
             logger (Logger): A Logger class instance containing the log file path and Logger type.
-            proxy (UserProxy) : An UserProxy class instance containing the proxy properties of the user.
+            proxy (RequestProxy) : A RequestProxy class instance containing the proxy properties of the user.
         """
 
         try:
@@ -89,14 +90,16 @@ class Initializer(object):
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
-            if auto_refresh_fields is None:
-                raise SDKException(Constants.INITIALIZATION_ERROR, Constants.AUTO_REFRESH_FIELDS_ERROR_MESSAGE)
+            if not isinstance(sdk_config, SDKConfig):
+                error = {Constants.FIELD: Constants.SDK_CONFIG, Constants.EXPECTED_TYPE: SDKConfig.__module__}
+
+                raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
             if resource_path is None or len(resource_path) == 0:
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.RESOURCE_PATH_ERROR_MESSAGE)
 
-            if proxy is not None and not isinstance(proxy, UserProxy):
-                error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: UserProxy.__module__}
+            if proxy is not None and not isinstance(proxy, RequestProxy):
+                error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: RequestProxy.__module__}
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
@@ -112,9 +115,9 @@ class Initializer(object):
             initializer.user = user
             initializer.token = token
             initializer.store = store
-            initializer.auto_refresh_fields = auto_refresh_fields
+            initializer.sdk_config = sdk_config
             initializer.resource_path = resource_path
-            initializer.user_proxy = proxy
+            initializer.request_proxy = proxy
 
             Initializer.initializer = initializer
 
@@ -123,10 +126,9 @@ class Initializer(object):
         except SDKException as e:
             raise e
 
-        dir_name = os.path.dirname(__file__)
-        filename = os.path.join(dir_name, '..', '..', '..', '..', Constants.JSON_DETAILS_FILE_PATH)
+        json_details_path = os.path.join(os.path.dirname(__file__), '..', '..', '..', '..', Constants.JSON_DETAILS_FILE_PATH)
 
-        with open(filename, mode='r') as JSON:
+        with open(json_details_path, mode='r') as JSON:
             Initializer.json_details = json.load(JSON)
 
     def __str__(self):
@@ -156,7 +158,7 @@ class Initializer(object):
         return file_contents
 
     @staticmethod
-    def switch_user(user, environment, token, auto_refresh_fields, proxy=None):
+    def switch_user(user, environment, token, sdk_config, proxy=None):
 
         """
         The method to switch the different user in SDK environment.
@@ -165,8 +167,8 @@ class Initializer(object):
             user (UserSignature) : A UserSignature class instance represents the CRM user
             environment (DataCenter.Environment) : An Environment class instance containing the CRM API base URL and Accounts URL.
             token (Token) : A Token class instance containing the OAuth client application information.
-            auto_refresh_fields (bool) : A Boolean value to allow or prevent auto-refreshing of the modules' fields in the background.
-            proxy (UserProxy) : An UserProxy class instance containing the proxy properties of the user.
+            sdk_config (SDKConfig) : A SDKConfig class instance containing the configuration.
+            proxy (RequestProxy) : A RequestProxy class instance containing the proxy properties of the user.
         """
 
         if not isinstance(user, UserSignature):
@@ -185,11 +187,13 @@ class Initializer(object):
 
             raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
 
-        if auto_refresh_fields is None:
-            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.AUTO_REFRESH_FIELDS_ERROR_MESSAGE)
+        if not isinstance(sdk_config, SDKConfig):
+            error = {Constants.FIELD: Constants.SDK_CONFIG, Constants.EXPECTED_TYPE: SDKConfig.__module__}
 
-        if proxy is not None and not isinstance(proxy, UserProxy):
-            error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: UserProxy.__module__}
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
+
+        if proxy is not None and not isinstance(proxy, RequestProxy):
+            error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: RequestProxy.__module__}
 
             raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
 
@@ -198,10 +202,10 @@ class Initializer(object):
         initializer.user = user
         initializer.environment = environment
         initializer.token = token
-        initializer.auto_refresh_fields = auto_refresh_fields
+        initializer.sdk_config = sdk_config
         initializer.store = Initializer.initializer.store
         initializer.resource_path = Initializer.initializer.resource_path
-        initializer.user_proxy = proxy
+        initializer.request_proxy = proxy
 
         Initializer.LOCAL.init = initializer
 
