@@ -19,7 +19,7 @@ class Argument(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -43,7 +43,7 @@ class Argument(object):
 		The method to get the value
 
 		Returns:
-			string: A string value
+			string: A string representing the value
 		"""
 
 		return self.__value
@@ -70,7 +70,7 @@ class Argument(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
