@@ -1,4 +1,4 @@
-from .related_lists_operations import RelatedListsOperations
+from .related_lists_operations import RelatedListsOperations, GetRelatedListsParam, GetRelatedListParam
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .response_wrapper import ResponseWrapper
