@@ -67,7 +67,8 @@ class Constants(object):
         "Double": float,
         "Float": float,
         "DateTime": datetime.datetime,
-        "Date": datetime.date
+        "Date": datetime.date,
+        "Boolean": bool
     }
 
     OBJECT_KEY = "object"
@@ -178,11 +179,11 @@ class Constants(object):
 
     PRIMARY = "primary"
 
-    MANDATORY_VALUE_MISSING_ERROR = "MANDATORY VALUE MISSING ERROR"
+    MANDATORY_VALUE_ERROR = "MANDATORY VALUE ERROR"
 
     MANDATORY_VALUE_NULL_ERROR = "MANDATORY VALUE NULL ERROR"
 
-    MANDATORY_KEY_MISSING_ERROR = "Value missing for mandatory key(s): "
+    MANDATORY_KEY_ERROR = "Value missing or None for mandatory key(s): "
 
     MANDATORY_KEY_NULL_ERROR = "Null Value for mandatory key : "
 
@@ -214,6 +215,8 @@ class Constants(object):
 
     REMINDAT_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RemindAt"
 
+    CONSENT_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Consent"
+
     LINE_TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.LineTax"
 
     REMINDER_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Reminder"
@@ -258,6 +261,8 @@ class Constants(object):
 
     TOKEN = "token"
 
+    SDK_CONFIG = "sdk_config"
+
     USER_PROXY = "proxy"
 
     JSON_DETAILS_FILE_PATH = 'json_details.json'
@@ -438,7 +443,7 @@ class Constants(object):
 
     ACCOUNTS = "accounts"
 
-    PRIMARY_KEY_MISSING_ERROR = "Value missing for required key(s) : "
+    PRIMARY_KEY_ERROR = "Value missing or None for required key(s) : "
 
     REFRESH_SINGLE_MODULE_FIELDS_ERROR = "Exception in refreshing fields of module : "
 
@@ -500,3 +505,12 @@ class Constants(object):
 
     ATTACHMENTS = "$attachments"
 
+    PROXY_SETTINGS = "Proxy settings - "
+
+    PROXY_HOST = "Host: "
+
+    PROXY_PORT = "Port: "
+
+    PROXY_USER = "User: "
+
+    JSON_FILE_EXTENSION = ".json"
