@@ -2,7 +2,6 @@ try:
     from abc import ABC, abstractmethod
     import logging
     import sys
-    import traceback
     import zlib
     import base64
     import re
@@ -14,7 +13,6 @@ except Exception:
     from abc import ABC, abstractmethod
     import logging
     import sys
-    import traceback
     import zlib
     import base64
     import re
@@ -103,10 +101,12 @@ class Converter(ABC):
         try:
             from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
             from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
 
         except Exception:
             from ..exception import SDKException
             from .constants import Constants
+            from ..initializer import Initializer
 
         details_jo = {}
         name = key_details[Constants.NAME]
@@ -128,7 +128,7 @@ class Converter(ABC):
                         check = False
                         instance_number = index
                         data_type = Constants.LIST_KEY + '[' + structure_name + ']'
-                        given_type = each_instance.__class__.__module__
+                        given_type = each_instance.__module__
                         break
 
                     index = index + 1
@@ -151,11 +151,12 @@ class Converter(ABC):
             details_jo[Constants.CLASS] = class_name
             details_jo[Constants.ACCEPTED_TYPE] = data_type
             details_jo[Constants.GIVEN_TYPE] = given_type
-            details_jo[Constants.INDEX] = instance_number
+            if instance_number is not None:
+                details_jo[Constants.INDEX] = instance_number
 
-            raise SDKException(Constants.TYPE_ERROR, None, details_jo, traceback.format_stack(limit=6))
+            raise SDKException(code=Constants.TYPE_ERROR, details=details_jo)
 
-        if Constants.VALUES in key_details:
+        if Constants.VALUES in key_details and (Constants.PICKLIST not in key_details or (key_details[Constants.PICKLIST] and Initializer.get_initializer().sdk_config.get_pick_list_validation())):
             values_ja = key_details[Constants.VALUES]
 
             if isinstance(value, Choice):
@@ -164,10 +165,11 @@ class Converter(ABC):
             if value not in values_ja:
                 details_jo[Constants.FIELD] = member_name
                 details_jo[Constants.CLASS] = class_name
-                details_jo[Constants.INDEX] = instance_number
                 details_jo[Constants.ACCEPTED_VALUES] = values_ja
-                raise SDKException(Constants.UNACCEPTED_VALUES_ERROR, None, details=details_jo,
-                                   cause=traceback.format_stack(limit=6))
+                if instance_number is not None:
+                    details_jo[Constants.INDEX] = instance_number
+
+                raise SDKException(code=Constants.UNACCEPTED_VALUES_ERROR, details=details_jo)
 
         if Constants.UNIQUE in key_details:
             if name not in unique_values_map:
@@ -181,8 +183,8 @@ class Converter(ABC):
                 details_jo[Constants.FIRST_INDEX] = values_array.index(value) + 1
                 details_jo[Constants.NEXT_INDEX] = instance_number
 
-                raise SDKException(Constants.UNIQUE_KEY_ERROR, None, details=details_jo,
-                                   cause=traceback.format_stack(limit=6))
+                raise SDKException(code=Constants.UNIQUE_KEY_ERROR, details=details_jo)
+
             else:
                 unique_values_map[name].append(value)
 
@@ -198,8 +200,7 @@ class Converter(ABC):
                 details_jo[Constants.GIVEN_LENGTH] = count
                 details_jo[Constants.MAXIMUM_LENGTH] = key_details[Constants.MAX_LENGTH]
 
-                raise SDKException(Constants.MAXIMUM_LENGTH_ERROR, None, details=details_jo,
-                                   cause=traceback.format_stack(limit=6))
+                raise SDKException(code=Constants.MAXIMUM_LENGTH_ERROR, details=details_jo)
 
             if Constants.MIN_LENGTH in key_details and count < key_details[Constants.MIN_LENGTH]:
                 details_jo[Constants.FIELD] = member_name
@@ -207,8 +208,7 @@ class Converter(ABC):
                 details_jo[Constants.GIVEN_LENGTH] = count
                 details_jo[Constants.MINIMUM_LENGTH] = key_details[Constants.MIN_LENGTH]
 
-                raise SDKException(Constants.MINIMUM_LENGTH_ERROR, None, details=details_jo,
-                                   cause=traceback.format_stack(limit=6))
+                raise SDKException(code=Constants.MINIMUM_LENGTH_ERROR, details=details_jo)
 
         if Constants.REGEX in key_details:
             if re.search(value, key_details[Constants.REGEX]) is None:
@@ -216,8 +216,7 @@ class Converter(ABC):
                 details_jo[Constants.CLASS] = class_name
                 details_jo[Constants.INSTANCE_NUMBER] = instance_number
 
-                raise SDKException(Constants.REGEX_MISMATCH_ERROR, None, details=details_jo,
-                                   cause=traceback.format_stack(limit=6))
+                raise SDKException(code=Constants.REGEX_MISMATCH_ERROR, details=details_jo)
 
         return True
 
