@@ -1,13 +1,11 @@
 try:
     import importlib
     import re
-    import traceback
     import json
     from zcrmsdk.src.com.zoho.crm.api.util import Converter, Constants, DataTypeConverter, Utility
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
 except Exception:
     import importlib
-    import traceback
     import re
     from ..exception import SDKException
     from .converter import Converter
@@ -18,7 +16,7 @@ except Exception:
 
 class JSONConverter(Converter):
     """
-    This class processes the API response object to the POJO object and POJO object to a JSON object.
+    This class processes the API response to the object and an object to a JSON object, containing the request body.
     """
 
     def __init__(self, common_api_handler):
@@ -64,9 +62,9 @@ class JSONConverter(Converter):
             from ..record import Record
 
         if isinstance(request_instance, Record):
-            module_api_name = self.common_api_handler.module_api_name
+            module_api_name = self.common_api_handler.get_module_api_name()
             return_json = self.is_record_request(request_instance, class_detail, instance_number, class_member_detail)
-            self.common_api_handler.module_api_name = module_api_name
+            self.common_api_handler.set_module_api_name(module_api_name)
             return return_json
 
         else:
@@ -83,11 +81,11 @@ class JSONConverter(Converter):
         class_member_name = None
         if class_member_detail is not None:
             lookup = class_member_detail[Constants.LOOKUP] if Constants.LOOKUP in class_member_detail else False
-            skip_mandatory = class_member_detail[Constants.SKIP_MANDATORY] if Constants.SKIP_MANDATORY in member_detail else False
+            skip_mandatory = class_member_detail[Constants.SKIP_MANDATORY] if Constants.SKIP_MANDATORY in class_member_detail else False
             class_member_name = class_member_detail[Constants.NAME]
 
         request_json = {}
-        required_keys, primary_keys = [], []
+        required_keys, primary_keys, required_in_update_keys = [], [], []
 
         for member_name, member_detail in class_detail.items():
             if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
@@ -103,11 +101,10 @@ class JSONConverter(Converter):
             if Constants.REQUIRED in member_detail and member_detail[Constants.REQUIRED]:
                 required_keys.append(key_name)
 
-            required_in_update = True
-            if Constants.REQUIRED_IN_UPDATE in member_detail:
-                required_in_update = member_detail[Constants.REQUIRED_IN_UPDATE]
+            if Constants.REQUIRED_IN_UPDATE in member_detail and member_detail[Constants.REQUIRED_IN_UPDATE]:
+                required_in_update_keys.append(key_name)
 
-            if Constants.PRIMARY in member_detail and member_detail[Constants.PRIMARY] and required_in_update:
+            if Constants.PRIMARY in member_detail and member_detail[Constants.PRIMARY] and (Constants.REQUIRED_IN_UPDATE not in member_detail or member_detail[Constants.REQUIRED_IN_UPDATE]):
                 primary_keys.append(key_name)
 
             if modification is not None and modification != 0:
@@ -117,14 +114,15 @@ class JSONConverter(Converter):
                 if self.value_checker(class_name=class_name, member_name=member_name, key_details=member_detail,
                                       value=field_value, unique_values_map=self.unique_dict,
                                       instance_number=instance_number) is True:
-                    if field_value is None and not skip_mandatory:
-                        self.mandatory_check(request_instance, member_name, member_detail, lookup, skip_mandatory)
+                    if field_value is not None:
+                        if key_name in required_keys:
+                            required_keys.remove(key_name)
 
-                    if key_name in required_keys:
-                        required_keys.remove(key_name)
+                        if key_name in primary_keys:
+                            primary_keys.remove(key_name)
 
-                    if key_name in primary_keys:
-                        primary_keys.remove(key_name)
+                        if key_name in required_in_update_keys:
+                            required_in_update_keys.remove(key_name)
 
                     if isinstance(request_instance, FileDetails):
                         if key_name.lower() == Constants.ATTACHMENT_ID.lower():
@@ -139,51 +137,70 @@ class JSONConverter(Converter):
                     else:
                         request_json[key_name] = self.set_data(member_detail, field_value)
 
-        if not skip_mandatory and self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker:
-            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
+        if skip_mandatory or self.check_exception(class_member_name, request_instance, instance_number, lookup, required_keys, primary_keys, required_in_update_keys) is True:
+            return request_json
+
+    def check_exception(self, member_name, request_instance, instance_number, lookup, required_keys, primary_keys, required_in_update_keys):
+        if len(required_in_update_keys) and self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE:
+            error = {
+                Constants.FIELD: member_name,
+                Constants.TYPE: request_instance.__module__,
+                Constants.KEYS: str(primary_keys)
+            }
+            if instance_number is not None:
+                error[Constants.INSTANCE_NUMBER] = instance_number
+
+            raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.MANDATORY_KEY_ERROR, error)
+
+        if self.common_api_handler.get_mandatory_checker() is not None and self.common_api_handler.get_mandatory_checker():
+            if self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_CREATE:
                 if lookup:
                     if len(primary_keys) > 0:
                         error = {
-                            Constants.FIELD: class_member_name,
-                            Constants.TYPE: request_instance.__class__.__name__,
-                            Constants.KEYS: str(primary_keys),
-                            Constants.INSTANCE_NUMBER: instance_number
+                            Constants.FIELD: member_name,
+                            Constants.TYPE: request_instance.__module__,
+                            Constants.KEYS: str(primary_keys)
                         }
-                        raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
-                                           error)
+                        if instance_number is not None:
+                            error[Constants.INSTANCE_NUMBER] = instance_number
+
+                        raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.MANDATORY_KEY_ERROR, error)
 
                 elif len(required_keys) > 0:
                     error = {
-                        Constants.FIELD: class_member_name,
-                        Constants.TYPE: request_instance.__class__.__name__,
-                        Constants.KEYS: str(required_keys),
-                        Constants.INSTANCE_NUMBER: instance_number
+                        Constants.FIELD: member_name,
+                        Constants.TYPE: request_instance.__module__,
+                        Constants.KEYS: str(required_keys)
                     }
-                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.MANDATORY_KEY_MISSING_ERROR,
-                                       error)
+                    if instance_number is not None:
+                        error[Constants.INSTANCE_NUMBER] = instance_number
 
-            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
-                if len(primary_keys) > 0:
-                    error = {
-                        Constants.FIELD: class_member_name,
-                        Constants.TYPE: request_instance.__class__.__name__,
-                        Constants.KEYS: str(primary_keys),
-                        Constants.INSTANCE_NUMBER: instance_number
-                    }
-                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
-                                       error)
+                    raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.MANDATORY_KEY_ERROR, error)
 
-        elif not skip_mandatory and lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
+            if self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE and len(primary_keys) > 0:
+                error = {
+                    Constants.FIELD: member_name,
+                    Constants.TYPE: request_instance.__module__,
+                    Constants.KEYS: str(primary_keys)
+                }
+                if instance_number is not None:
+                    error[Constants.INSTANCE_NUMBER] = instance_number
+
+                raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.PRIMARY_KEY_ERROR, error)
+
+        elif lookup and self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE:
             if len(primary_keys) > 0:
                 error = {
-                    Constants.FIELD: class_member_name,
-                    Constants.TYPE: request_instance.__class__.__name__,
-                    Constants.KEYS: str(primary_keys),
-                    Constants.INSTANCE_NUMBER: instance_number
+                    Constants.FIELD: member_name,
+                    Constants.TYPE: request_instance.__module__,
+                    Constants.KEYS: str(primary_keys)
                 }
-                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR, error)
+                if instance_number is not None:
+                    error[Constants.INSTANCE_NUMBER] = instance_number
 
-        return request_json
+                raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.PRIMARY_KEY_ERROR, error)
+
+        return True
 
     def is_record_request(self, record_instance, class_detail, instance_number, member_detail):
         try:
@@ -201,11 +218,11 @@ class JSONConverter(Converter):
             class_member_name = member_detail[Constants.NAME]
 
         request_json, module_detail = {}, {}
-        module_api_name = self.common_api_handler.module_api_name
+        module_api_name = self.common_api_handler.get_module_api_name()
         class_name = record_instance.__class__.__name__
 
         if module_api_name is not None:
-            self.common_api_handler.module_api_name = None
+            self.common_api_handler.set_module_api_name(None)
             full_detail = Utility.search_json_details(module_api_name)
 
             if full_detail is not None:
@@ -273,67 +290,22 @@ class JSONConverter(Converter):
                     continue
 
                 if self.value_checker(class_name, key_name, key_detail, key_value, self.unique_dict, instance_number):
-                    if key_value is None:
-                        self.mandatory_check(record_instance, key_name, key_detail, lookup, skip_mandatory)
-
                     json_value = self.set_data(key_detail, key_value)
 
             else:
                 json_value = self.redirector_for_object_to_json(key_value)
 
-            if key_name in required_keys:
-                required_keys.remove(key_name)
+            if key_value is not None:
+                if key_name in required_keys:
+                    required_keys.remove(key_name)
 
-            if key_name in primary_keys:
-                primary_keys.remove(key_name)
+                if key_name in primary_keys:
+                    primary_keys.remove(key_name)
 
             request_json[key_name] = json_value
 
-        if self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker and not skip_mandatory:
-            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
-                if lookup:
-                    if len(primary_keys) > 0:
-                        error = {
-                            Constants.FIELD: class_member_name,
-                            Constants.TYPE: record_instance.__class__.__name__,
-                            Constants.KEYS: str(primary_keys),
-                            Constants.INSTANCE_NUMBER: instance_number
-                        }
-                        raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
-                                           error)
-
-                elif len(required_keys) > 0:
-                    error = {
-                        Constants.FIELD: class_member_name,
-                        Constants.TYPE: record_instance.__class__.__name__,
-                        Constants.KEYS: str(required_keys),
-                        Constants.INSTANCE_NUMBER: instance_number
-                    }
-                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.MANDATORY_KEY_MISSING_ERROR,
-                                       error)
-
-            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
-                if len(primary_keys) > 0:
-                    error = {
-                        Constants.FIELD: class_member_name,
-                        Constants.TYPE: record_instance.__class__.__name__,
-                        Constants.KEYS: str(primary_keys),
-                        Constants.INSTANCE_NUMBER: instance_number
-                    }
-                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
-                                       error)
-
-        elif lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and not skip_mandatory:
-            if len(primary_keys) > 0:
-                error = {
-                    Constants.FIELD: class_member_name,
-                    Constants.TYPE: record_instance.__class__.__name__,
-                    Constants.KEYS: str(primary_keys),
-                    Constants.INSTANCE_NUMBER: instance_number
-                }
-                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR, error)
-
-        return request_json
+        if skip_mandatory or self.check_exception(class_member_name, record_instance, instance_number, lookup, required_keys, primary_keys, []) is True:
+            return request_json
 
     def set_data(self, member_detail, field_value):
         if field_value is not None:
@@ -349,10 +321,10 @@ class JSONConverter(Converter):
                 return field_value.get_value()
 
             elif Constants.STRUCTURE_NAME in member_detail and Constants.MODULE in member_detail:
-                return self.is_record_request(field_value, self.__get_module_detail_from_user_spec_json(member_detail[Constants.MODULE]), 0, member_detail)
+                return self.is_record_request(field_value, self.__get_module_detail_from_user_spec_json(member_detail[Constants.MODULE]), None, member_detail)
 
             elif Constants.STRUCTURE_NAME in member_detail:
-                return self.form_request(field_value, member_detail[Constants.STRUCTURE_NAME], 0, member_detail)
+                return self.form_request(field_value, member_detail[Constants.STRUCTURE_NAME], None, member_detail)
 
             else:
                 return DataTypeConverter.post_convert(field_value, data_type)
@@ -421,33 +393,6 @@ class JSONConverter(Converter):
         else:
             return request
 
-    def mandatory_check(self, instance, member_name, member_detail, lookup, skip_mandatory):
-        is_required = member_detail[Constants.REQUIRED] if Constants.REQUIRED in member_detail else False
-        is_primary = member_detail[Constants.PRIMARY] if Constants.PRIMARY in member_detail else False
-
-        if not skip_mandatory:
-            if not lookup:
-                if is_required and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
-                    error = {
-                        Constants.FIELD: member_name,
-                        Constants.TYPE: instance.__class__.__name__
-                    }
-                    raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
-
-                if is_required and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
-                    error = {
-                        Constants.FIELD: member_name,
-                        Constants.TYPE: instance.__class__.__name__
-                    }
-                    raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
-
-            if is_primary and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker:
-                error = {
-                    Constants.FIELD: member_name,
-                    Constants.TYPE: instance.__class__.__name__
-                }
-                raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
-
     def get_wrapped_response(self, response, pack):
         try:
             return self.get_response(response.json(), pack)
@@ -486,9 +431,9 @@ class JSONConverter(Converter):
                 from ..record import Record
 
             if isinstance(instance, Record):
-                module_api_name = self.common_api_handler.module_api_name
+                module_api_name = self.common_api_handler.get_module_api_name()
                 instance = self.is_record_response(response_json, class_detail, package_name)
-                self.common_api_handler.module_api_name = module_api_name
+                self.common_api_handler.set_module_api_name(module_api_name)
 
             else:
                 instance = self.not_record_response(instance=instance, class_name=class_name,
@@ -516,13 +461,13 @@ class JSONConverter(Converter):
 
         response_json = dict(response_json)
         record_instance = JSONConverter.__get_instance_from_name(pack)
-        module_api_name = self.common_api_handler.module_api_name
+        module_api_name = self.common_api_handler.get_module_api_name()
 
-        module_detail = None
+        module_detail = {}
         class_name = Constants.RECORD_NAMESPACE.rpartition('.')[-1]
 
         if module_api_name is not None:
-            self.common_api_handler.module_api_name = None
+            self.common_api_handler.set_module_api_name(None)
             full_detail = Utility.search_json_details(module_api_name)
 
             if full_detail is not None:
@@ -532,9 +477,11 @@ class JSONConverter(Converter):
 
             else:
                 module_detail = self.__get_module_detail_from_user_spec_json(module_api_name)
-        else:
-            module_detail = class_detail
-            class_detail = Initializer.json_details[Constants.RECORD_NAMESPACE]
+
+        for key, value in class_detail.items():
+            module_detail[key] = value
+
+        record_detail = Initializer.json_details[Constants.RECORD_NAMESPACE]
 
         class_list = record_instance.__class__.mro()
 
@@ -552,8 +499,8 @@ class JSONConverter(Converter):
             if len(module_detail) > 0 and (key_name in module_detail or member_name in module_detail):
                 key_detail = module_detail[key_name] if key_name in module_detail.keys() else module_detail[member_name]
 
-            elif member_name in class_detail:
-                key_detail = class_detail[member_name]
+            elif member_name in record_detail:
+                key_detail = record_detail[member_name]
 
             key_data = response_json[key_name]
             key_value = None
