@@ -76,13 +76,13 @@ class Utility(object):
                 if os.path.exists(record_field_details_path):
                     record_field_details_json = Initializer.get_json(record_field_details_path)
 
-                    if Initializer.get_initializer().auto_refresh_fields and not Utility.new_file and not Utility.get_modified_modules and (Constants.FIELDS_LAST_MODIFIED_TIME not in record_field_details_json or Utility.force_refresh or (time.time() * 1000 - record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]) > 3600000):
+                    if Initializer.get_initializer().sdk_config.get_auto_refresh_fields() and not Utility.new_file and not Utility.get_modified_modules and (Constants.FIELDS_LAST_MODIFIED_TIME not in record_field_details_json or Utility.force_refresh or (time.time() * 1000 - record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]) > 3600000):
                         Utility.get_modified_modules = True
                         last_modified_time = record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None
                         Utility.modify_fields(record_field_details_path, last_modified_time)
                         Utility.get_modified_modules = False
 
-                    elif not Initializer.get_initializer().auto_refresh_fields and Utility.force_refresh and not Utility.get_modified_modules:
+                    elif not Initializer.get_initializer().sdk_config.get_auto_refresh_fields() and Utility.force_refresh and not Utility.get_modified_modules:
                         Utility.get_modified_modules = True
                         Utility.modify_fields(record_field_details_path, last_modified_time)
                         Utility.get_modified_modules = False
@@ -101,7 +101,7 @@ class Utility(object):
                         record_field_details_json[module_api_name.lower()] = field_details
                         Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
-                elif Initializer.get_initializer().auto_refresh_fields:
+                elif Initializer.get_initializer().sdk_config.get_auto_refresh_fields():
                     Utility.new_file = True
                     Utility.fill_data_type()
                     module_api_names = Utility.get_modules(None)
@@ -189,7 +189,7 @@ class Utility(object):
     def delete_fields(record_field_details_json, module):
         subform_modules = []
         fields_json = record_field_details_json[module.lower()]
-        for key,value in fields_json.items():
+        for key, value in fields_json.items():
             if Constants.SUBFORM in value and value[Constants.SUBFORM]:
                 subform_modules.append(value[Constants.MODULE])
 
@@ -250,10 +250,11 @@ class Utility(object):
         for related_list_jo in module_related_list_array:
             if related_list_jo[Constants.API_NAME] is not None and related_list_jo[Constants.API_NAME].lower() == related_module_name.lower():
                 if related_list_jo[Constants.HREF] == Constants.NULL_VALUE:
-                    raise SDKException(code=Constants.UNSUPPORTED_IN_API, message=common_api_handler.http_method + ' ' + common_api_handler.api_path + Constants.UNSUPPORTED_IN_API_MESSAGE)
+                    raise SDKException(code=Constants.UNSUPPORTED_IN_API, message=common_api_handler.get_http_method() + ' ' + common_api_handler.get_api_path() + Constants.UNSUPPORTED_IN_API_MESSAGE)
 
-                common_api_handler.module_api_name = related_list_jo[Constants.MODULE]
-                Utility.get_fields(related_list_jo[Constants.MODULE])
+                if related_list_jo[Constants.MODULE] != Constants.NULL_VALUE:
+                    common_api_handler.set_module_api_name(related_list_jo[Constants.MODULE])
+                    Utility.get_fields(related_list_jo[Constants.MODULE])
                 return True
 
         return False
@@ -280,7 +281,7 @@ class Utility(object):
                     for related_list in related_lists:
                         related_list_detail = {
                             Constants.API_NAME: related_list.get_api_name(),
-                            Constants.MODULE: related_list.get_module(),
+                            Constants.MODULE: related_list.get_module() if related_list.get_module() is not None else Constants.NULL_VALUE,
                             Constants.NAME: related_list.get_name(),
                             Constants.HREF: related_list.get_href() if related_list.get_href() is not None else Constants.NULL_VALUE
                         }
@@ -514,6 +515,7 @@ class Utility(object):
             field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
 
         if api_type.lower() == Constants.PICKLIST and field.get_pick_list_values() is not None and len(field.get_pick_list_values()) > 0:
+            field_detail[Constants.PICKLIST] = True
             values = list(map(lambda x: x.get_display_value(), field.get_pick_list_values()))
             field_detail[Constants.VALUES] = values
 
@@ -543,6 +545,9 @@ class Utility(object):
 
     @staticmethod
     def fill_data_type():
+        if len(Utility.apitype_vs_datatype) > 0:
+            return
+
         field_api_names_string = ["textarea", "text", "website", "email", "phone", "mediumtext", "multiselectlookup",
                                   "profileimage"]
 
@@ -582,6 +587,8 @@ class Utility(object):
 
         field_api_name_reminder = ['multireminder']
 
+        field_api_name_consent_lookup = ['consent_lookup']
+
         for field_api_name in field_api_names_string:
             Utility.apitype_vs_datatype[field_api_name] = Constants.STRING_NAMESPACE
 
@@ -649,6 +656,10 @@ class Utility(object):
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
             Utility.apitype_vs_structurename[field_api_name] = Constants.REMINDER_NAMESPACE
 
+        for field_api_name in field_api_name_consent_lookup:
+            Utility.apitype_vs_datatype[field_api_name] = Constants.CONSENT_NAMESPACE
+            Utility.apitype_vs_structurename[field_api_name] = Constants.CONSENT_NAMESPACE
+
     @staticmethod
     def write_to_file(file_path, file_contents):
         with open(file_path, mode="w") as file:
